@@ -28,7 +28,7 @@ from werkzeug.exceptions import RequestEntityTooLarge, UnsupportedMediaType
 
 from . import utils
 
-__version__ = '0.8.0'
+__version__ = '0.8.1'
 
 
 IMAGES = ('.jpg', '.jpeg', '.png', '.gif', '.bmp')
@@ -259,7 +259,7 @@ class FileStorage(object):
         
         data = {
             'name': filename,
-            'path': filepath,
+            'relpath': filepath,
             'size': filesize,
             'content_type': filesto.content_type,
             'remote_url': None,
@@ -299,7 +299,7 @@ class File(object):
     def __init__(self, data, base_path, base_url):
         data = data or {}
         self.name = data.get('name', u'')
-        self.path = data.get('path', '').strip('/')
+        self.relpath = data.get('relpath', '').strip('/')
         self.size = data.get('size', u'')
         self.type = data.get('type', u'')
         self.remote_url = data.get('remote_url')
@@ -312,20 +312,20 @@ class File(object):
         
         self.is_image = self.type.startswith('image/')
 
-        fullpath = ''
-        if self.path:
-            fullpath = os.path.join(self.base_path, self.path, self.name)
-        self.fullpath = fullpath
+        path = ''
+        if self.relpath:
+            path = os.path.join(self.base_path, self.relpath, self.name)
+        self.path = path
 
         url = ''
         if self.remote_url:
             url = self.remote_url
-        elif self.path:
-            url = '%s/%s/%s' % (self.base_url, self.path, self.name)    
+        elif self.relpath:
+            url = '%s/%s/%s' % (self.base_url, self.relpath, self.name)    
         self.url = url
     
     def __nonzero__(self):
-        return self.path is not None
+        return bool(self.path)
     
     def __repr__(self):
         return '<%s %s "%s">' % (self.__class__.__name__,
@@ -342,7 +342,7 @@ class File(object):
         """
         data = {
             'name': self.name,
-            'path': self.path,
+            'relpath': self.relpath,
             'size': self.size,
             'type': self.type,
             'remote_url': self.remote_url,
